import os
import click
import grp, pwd
import subprocess
import sys

# We run Odoo as odoo system user but later we need root privs back.
def drop_root():
    u_id = pwd.getpwnam(os.getenv('ODOO_SYSTEM_USER')).pw_uid
    g_id = grp.getgrnam(os.getenv('ODOO_SYSTEM_GROUP')).gr_gid
    os.setgid(g_id)
    os.setuid(u_id)


@click.command('install')
@click.argument('name')
@click.pass_context
def cli(ctx, name):
    odoo_path = subprocess.check_output('which odoo', shell=True).decode().strip('\n')
    click.echo('Using Odoo at {}'.format(odoo_path))
    run_params = [odoo_path, '-c', 'odoo.conf', '-d',
                  os.getenv('ODOO_DB'), '-i', name, '--stop-after-init', '--no-http']
    data = subprocess.Popen(run_params, preexec_fn=drop_root,
                        cwd=os.path.join(os.getenv('AMANITA_PREFIX'), 'odoo'), 
                        stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    for line in iter(data.stdout.readline, b''):
        click.echo(line.decode().strip('\n'))
    exitcode = data.wait()
    if exitcode != 0:
        click.secho('Odoo addon {} install exit code: {}'.format(
                    name, exitcode), bold=True, fg='red')
        sys.exit(exitcode)
